"""Provides:
  1. Toolkit for testing factor strategies
  2. A lot of financial metrics to assess portfolios performance
  3. Fancy visualization of results

Source: https://github.com/atomtosov/pqr/tree/dev

Affiliation: https://fmlab.hse.ru/
"""

from .attribution import *
from .benchmarks import *
from .factor_models import *
from .factors import *
from .metrics import *
from .plotting import *
from .portfolios import *
from .tear_sheets import *
from .tests import *
